using System;
using System.ComponentModel;
using GalaSoft.MvvmLight;
using System.Collections.Generic;
using Benday.UserGroupManager.Common;

namespace Benday.UserGroupManager.Presentation
{
    public class MemberEditorViewModel : ViewModelBase
    {
        public MemberEditorViewModel(IMemberService memberService)
        {
            if (memberService == null)
            {
                throw new ArgumentNullException("memberService", "Argument cannot be null.");
            }

            MemberServiceInstance = memberService;

            m_id = 0;
            m_firstName = String.Empty;
            m_lastName = String.Empty;
            m_emailAddress = String.Empty;
            m_receiveEmails = false;
        }

        public MemberEditorViewModel(IMember model, IMemberService memberService)
        {
            if (model == null)
            {
                throw new ArgumentNullException("model", "Argument cannot be null.");
            }

            if (memberService == null)
            {
                throw new ArgumentNullException("memberService", "Argument cannot be null.");
            }

            m_id = model.Id;
            m_firstName = model.FirstName;
            m_lastName = model.LastName;
            m_emailAddress = model.EmailAddress;
            m_receiveEmails = model.ReceiveEmails;

            Model = model;
            MemberServiceInstance = memberService;
        }

        private IMemberService MemberServiceInstance { get; set; }

        private IMember m_model;
        private IMember Model
        {
            get { return m_model; }
            set { m_model = value; }
        }

        public void Save()
        {
            Model.Id = m_id;
            Model.FirstName = m_firstName;
            Model.LastName = m_lastName;
            Model.EmailAddress = m_emailAddress;
            Model.ReceiveEmails = m_receiveEmails;

            MemberServiceInstance.Save(Model);
        }

        private const string IdPropertyName = "Id";

        private int m_id;
        public int Id
        {
            get
            {
                return m_id;
            }
            set
            {
                m_id = value;
                RaisePropertyChanged(IdPropertyName);
            }
        }

        private const string FirstNamePropertyName = "FirstName";

        private string m_firstName;
        public string FirstName
        {
            get
            {
                return m_firstName;
            }
            set
            {
                m_firstName = value;
                RaisePropertyChanged(FirstNamePropertyName);
            }
        }

        private const string LastNamePropertyName = "LastName";

        private string m_lastName;
        public string LastName
        {
            get
            {
                return m_lastName;
            }
            set
            {
                m_lastName = value;
                RaisePropertyChanged(LastNamePropertyName);
            }
        }

        private const string EmailAddressPropertyName = "EmailAddress";

        private string m_emailAddress;
        public string EmailAddress
        {
            get
            {
                return m_emailAddress;
            }
            set
            {
                m_emailAddress = value;
                RaisePropertyChanged(EmailAddressPropertyName);
            }
        }

        private const string ReceiveEmailsPropertyName = "ReceiveEmails";

        private bool m_receiveEmails;
        public bool ReceiveEmails
        {
            get
            {
                return m_receiveEmails;
            }
            set
            {
                m_receiveEmails = value;
                RaisePropertyChanged(ReceiveEmailsPropertyName);
            }
        }
    }
}
